@@ -27,13 +27,24 @@ If not see: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html#SEC4
 namespace etr {
 
 // error function --> stop program & show message
-void ass(bool inp, std::string message) {
+inline void ass(bool inp, std::string message) {
   if(inp == false) {
-    std::cerr << message << std::endl;
-    Rcpp::stop("Error");
+      Rcpp::stop(message);
   }
 }
 
+/*
+#ifdef RLANG
+#else
+  namespace Rcpp {
+    void stop(std::string inp) {
+      std::cerr << inp << std::endl;
+      exit (EXIT_FAILURE);
+    }
+  }
+#endif
+*/
+
 /*
 // create range from start to end
 std::vector<double> range(int start, int end) {
